@@ -103,6 +103,90 @@ class QCticJob(BaseJob):
 
         return self._remote_job
 
+    @property
+    def time_submit(self):
+        """datetime.timedelta: Time spent by the job from submission to the 
+        moment it entered the queue. This includes the API network latency."""
+
+        date_submit = self.remote_job.get("date_submit")
+        date_queue = self.remote_job.get("date_queue")
+
+        if not date_submit or not date_queue:
+            return None
+
+        return date_queue - date_submit
+
+    @property
+    def time_enqueued(self):
+        """datetime.timedelta: Time spent by the job in the queue waiting to be executed."""
+
+        date_queue = self.remote_job.get("date_queue")
+        date_start = self.remote_job.get("date_start")
+
+        if not date_queue or not date_start:
+            return None
+
+        return date_start - date_queue
+
+    @property
+    def time_running(self):
+        """datetime.timedelta: Time spent by the job in an active worker 
+        including the environment initialization and simulation."""
+
+        date_start = self.remote_job.get("date_start")
+        date_end = self.remote_job.get("date_end")
+
+        if not date_start or not date_end:
+            return None
+
+        return date_end - date_start
+
+    @property
+    def time_simulation(self):
+        """datetime.timedelta: Time spent by the job in the actual simulation."""
+
+        date_ex_start = self.remote_job.get("date_execute_start")
+        date_ex_end = self.remote_job.get("date_execute_end")
+
+        if not date_ex_start or not date_ex_end:
+            return None
+
+        return date_ex_end - date_ex_start
+
+    @property
+    def time_total(self):
+        """datetime.timedelta: Total time spent by the job from submission 
+        to the moment the final simulation results are persisted."""
+
+        date_submit = self.remote_job.get("date_submit")
+        date_end = self.remote_job.get("date_end")
+
+        if not date_submit or not date_end:
+            return None
+
+        return date_end - date_submit
+
+    def get_simulation_ratio(self, queue=True):
+        """Returns the ratio between the time spent in the actual simulation and the total time 
+        including network latency, environment initialization and (optional) queue latency.
+
+        Args:
+            include_queue (bool): (Optional) Take the queue latency into account.
+
+        Returns:
+            float: The simulation ratio.
+        """
+
+        if not self.time_simulation or not self.time_total:
+            return None
+
+        if not queue and not self.time_enqueued:
+            return None
+
+        delta_total = self.time_total if queue else self.time_total - self.time_enqueued
+
+        return round(self.time_simulation.total_seconds() / delta_total.total_seconds(), 3)
+
     @property
     def submit_task(self):
         return self._submit_task if self._submit_task else _dummy_submit_task()
